@@ -1,4 +1,6 @@
-use crate::state::{attribute::Attribute, language::Language, oca::Overlay};
+use crate::state::{
+    attribute::Attribute, entries::EntriesElement, language::Language, oca::Overlay,
+};
 use serde::{Deserialize, Serialize};
 use std::collections::BTreeMap;
 
@@ -8,7 +10,7 @@ pub struct EntryOverlay {
     #[serde(rename = "type")]
     overlay_type: String,
     language: Language,
-    attr_entries: BTreeMap<String, BTreeMap<String, String>>,
+    attr_entries: BTreeMap<String, EntriesElement>,
 }
 
 impl Overlay for EntryOverlay {
@@ -38,7 +40,7 @@ impl EntryOverlay {
     pub fn new(lang: Language) -> Box<EntryOverlay> {
         Box::new(EntryOverlay {
             capture_base: String::new(),
-            overlay_type: "spec/overalys/entry/1.0".to_string(),
+            overlay_type: "spec/overlays/entry/1.0".to_string(),
             language: lang,
             attr_entries: BTreeMap::new(),
         })
