@@ -1,4 +1,4 @@
-use crate::state::{attribute::Attribute, oca::Overlay};
+use crate::state::{attribute::Attribute, entry_codes::EntryCodes, oca::Overlay};
 use serde::{Deserialize, Serialize};
 use std::collections::BTreeMap;
 
@@ -7,7 +7,7 @@ pub struct EntryCodeOverlay {
     capture_base: String,
     #[serde(rename = "type")]
     overlay_type: String,
-    attr_entry_codes: BTreeMap<String, Vec<String>>,
+    attr_entry_codes: BTreeMap<String, EntryCodes>,
 }
 
 impl Overlay for EntryCodeOverlay {
@@ -34,7 +34,7 @@ impl EntryCodeOverlay {
     pub fn new() -> Box<EntryCodeOverlay> {
         Box::new(EntryCodeOverlay {
             capture_base: String::new(),
-            overlay_type: "spec/overalys/entry_code/1.0".to_string(),
+            overlay_type: "spec/overlays/entry_code/1.0".to_string(),
             attr_entry_codes: BTreeMap::new(),
         })
     }
